==> ccache_4.2.orig.tar.xz: ccache-4.2/src/Manifest.hpp <==
// Copyright (C) 2009-2020 Joel Rosdahl and other contributors
//
// See doc/AUTHORS.adoc for a complete list of contributors.
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 3 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; if not, write to the Free Software Foundation, Inc., 51
// Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

#pragma once

#include "system.hpp"

#include "third_party/nonstd/optional.hpp"

#include <string>
#include <unordered_map>

class Config;
class Context;
class Digest;

namespace Manifest {

extern const std::string k_file_suffix;
extern const uint8_t k_magic[4];
extern const uint8_t k_version;

nonstd::optional<Digest> get(const Context& ctx, const std::string& path);
bool put(const Config& config,
         const std::string& path,
         const Digest& result_name,
         const std::unordered_map<std::string, Digest>& included_files,
         time_t time_of_compilation,
         bool save_timestamp);
bool dump(const std::string& path, FILE* stream);

} // namespace Manifest

==> ccache_4.5.1.orig.tar.xz: ccache-4.5.1/src/Manifest.hpp <==
// Copyright (C) 2009-2021 Joel Rosdahl and other contributors
//
// See doc/AUTHORS.adoc for a complete list of contributors.
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 3 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; if not, write to the Free Software Foundation, Inc., 51
// Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

#pragma once

#include "third_party/nonstd/optional.hpp"

#include <cstdint>
#include <cstdio>
#include <ctime>
#include <string>
#include <unordered_map>

class Config;
class Context;
class Digest;

namespace Manifest {

extern const std::string k_file_suffix;
extern const uint8_t k_magic[4];
extern const uint8_t k_version;

nonstd::optional<Digest> get(const Context& ctx, const std::string& path);
bool put(const Config& config,
         const std::string& path,
         const Digest& result_key,
         const std::unordered_map<std::string, Digest>& included_files,
         time_t time_of_compilation,
         bool save_timestamp);
bool dump(const std::string& path, FILE* stream);

} // namespace Manifest
